@@ -4,7 +4,7 @@ import os
 import json
 from pathlib import Path
 
-current_path = os.path.abspath(__file__).removesuffix("data.py")
+current_path = os.path.abspath(os.path.dirname(os.path.abspath(__file__)) + os.path.sep + ".") + "/"
 
 V_PATH = str(Path(f"{current_path}resources/voice").absolute()) + "/"
 T_PATH = str(Path(f"{current_path}resources/text").absolute()) + "/"
@@ -12,3 +12,7 @@ T_PATH = str(Path(f"{current_path}resources/text").absolute()) + "/"
 
 with open(f"{T_PATH}atri.json", "r", encoding="utf-8") as file:
     atri_text = json.load(file)
+
+
+if __name__ == "__main__":
+    print(current_path)
\ No newline at end of file
